@@ -1,4 +1,4 @@
-/* $Id: proclist.h,v 1.28 2003/10/20 20:11:58 hadess Exp $ */
+/* $Id: proclist.h,v 1.29 2004/07/18 20:33:55 bdejean Exp $ */
 
 /* Copyright (C) 1998-99 Martin Baulig
    This file is part of LibGTop 1.0.
@@ -72,20 +72,20 @@ struct _glibtop_proclist
 
 unsigned *
 glibtop_get_proclist_l (glibtop *server, glibtop_proclist *buf,
-			int64_t which, int64_t arg);
+			gint64 which, gint64 arg);
 
 #if GLIBTOP_SUID_PROCLIST
 void glibtop_init_proclist_p (glibtop *server);
 
 unsigned *
 glibtop_get_proclist_p (glibtop *server, glibtop_proclist *buf,
-			int64_t which, int64_t arg);
+			gint64 which, gint64 arg);
 #else
 void glibtop_init_proclist_s (glibtop *server);
 
 unsigned *
 glibtop_get_proclist_s (glibtop *server, glibtop_proclist *buf,
-			int64_t which, int64_t arg);
+			gint64 which, gint64 arg);
 #endif
 
 #ifdef GLIBTOP_NAMES
