@@ -1,4 +1,4 @@
-/* $Id: mem.c,v 1.21 2003/10/19 16:55:39 carlos Exp $ */
+/* $Id: mem.c,v 1.26 2004/07/03 13:28:59 bdejean Exp $ */
 
 /* Copyright (C) 1998-99 Martin Baulig
    This file is part of LibGTop 1.0.
@@ -46,36 +46,19 @@ glibtop_init_mem_s (glibtop *server)
 void
 glibtop_get_mem_s (glibtop *server, glibtop_mem *buf)
 {
-	char buffer [BUFSIZ], *p;
-	int fd, len;
+	char buffer [BUFSIZ];
 
 	glibtop_init_s (&server, GLIBTOP_SYSDEPS_MEM, 0);
 
-	memset (buf, 0, sizeof (glibtop_mem));
+	file_to_buffer(server, buffer, FILENAME);
 
-	fd = open (FILENAME, O_RDONLY);
-	if (fd < 0)
-		glibtop_error_io_r (server, "open (%s)", FILENAME);
-
-	len = read (fd, buffer, BUFSIZ-1);
-	if (len < 0)
-		glibtop_error_io_r (server, "read (%s)", FILENAME);
-
-	close (fd);
-
-	buffer [len] = '\0';
-
-	p = skip_line (buffer);
-	p = skip_token (p);		/* "Mem:" */
-
-	buf->total  = strtoul (p, &p, 0);
-	buf->used   = strtoul (p, &p, 0);
-	buf->free   = strtoul (p, &p, 0);
-	buf->shared = strtoul (p, &p, 0);
-	buf->buffer = strtoul (p, &p, 0);
-	buf->cached = strtoul (p, &p, 0);
+	buf->total  = get_scaled(buffer, "MemTotal:");
+	buf->free   = get_scaled(buffer, "MemFree:");
+	buf->used   = buf->total - buf->free;
+	buf->shared = 0;
+	buf->buffer = get_scaled(buffer, "Buffers:");
+	buf->cached = get_scaled(buffer, "Cached:");
 
 	buf->user = buf->total - buf->free - buf->cached - buf->buffer;
-
 	buf->flags = _glibtop_sysdeps_mem;
 }
