@@ -1,4 +1,4 @@
-/* $Id: proctime.c,v 1.28 2004/08/03 11:40:37 bdejean Exp $ */
+/* $Id: proctime.c,v 1.29 2004/08/09 07:55:50 bdejean Exp $ */
 
 /* Copyright (C) 1998-99 Martin Baulig
    This file is part of LibGTop 1.0.
@@ -74,9 +74,10 @@ glibtop_get_proc_time_s (glibtop *server, glibtop_proc_time *buf, pid_t pid)
 
 	p = skip_multiple_token (p, 3);
 
-	// timeout is 0 on 2.4 and "thread_number" on 2.6
-	// lets skip it (using previous skip_multiple_token)
-	// buf->timeout       = strtoull (p, &p, 0);
+	/* timeout is 0 on 2.4 and "thread_number" on 2.6
+	   lets skip it (using previous skip_multiple_token)
+	   buf->timeout       = strtoull (p, &p, 0);
+	*/
 	buf->it_real_value = strtoull (p, &p, 0);
 
 	/* seconds since epoch */
