@@ -1,4 +1,4 @@
-/* $Id: loadavg.c,v 1.10 2003/10/19 16:55:46 carlos Exp $ */
+/* $Id: loadavg.c,v 1.11 2004/05/25 17:07:20 bdejean Exp $ */
 
 /* Copyright (C) 1998-99 Martin Baulig
    This file is part of LibGTop 1.0.
@@ -52,7 +52,7 @@ glibtop_get_loadavg_s (glibtop *server, glibtop_loadavg *buf)
 	kstat_ctl_t *kc;
 	kstat_t *ksp;
 	int i;
-	static char *avestrings[] = { "avenrun_1min",
+	static const char *avestrings[] = { "avenrun_1min",
 	   			      "avenrun_5min",
 				      "avenrun_15min" };
 #endif
