@@ -1,4 +1,4 @@
-/* $Id: procmap.c,v 1.17 2004/03/09 23:02:04 hadess Exp $ */
+/* $Id: procmap.c,v 1.19 2004/06/09 18:52:22 bdejean Exp $ */
 
 /* Copyright (C) 1998-99 Martin Baulig
    This file is part of LibGTop 1.0.
@@ -74,7 +74,7 @@ glibtop_get_proc_map_s (glibtop *server, glibtop_proc_map *buf,	pid_t pid)
 	glibtop_map_entry *entry;
 	struct stat inode;
 	char buffer[BUFSIZ];
-	
+
 	memset (buf, 0, sizeof (glibtop_proc_map));
 
 #ifdef HAVE_PROCFS_H
@@ -120,13 +120,10 @@ glibtop_get_proc_map_s (glibtop *server, glibtop_proc_map *buf,	pid_t pid)
 		return NULL;
 	}
 #endif
-	if(!(entry = g_malloc(nmaps * sizeof(glibtop_map_entry))))
-	   	return NULL;
 	buf->number = nmaps;
 	buf->size = sizeof(glibtop_map_entry);
 	buf->total = nmaps * sizeof(glibtop_map_entry);
-
-	memset(entry, 0, nmaps * sizeof(glibtop_map_entry));
+	entry = g_malloc0(buf->total);
 
 #if GLIBTOP_SOLARIS_RELEASE >= 560
 
